#!/bin/bash

usage()
{
    cat <<EOF

  Usage:
      debfix-citrixpkg <packagefile>

      (with <packagefile> a .deb made by Citrix)

EOF
}

die()
{
    EC=${1}
    shift
    echo "$@"
    exit ${EC}
}

declare ORIGPKG

## Sanity checks
# What package do we have to fix?
if [ -z "${1}" ] ; then
    usage
    exit 1
fi
if ! file ${1}|grep -q "Debian binary package" ; then
    die 2 "${1} doesn't seem to be a Debian package, quitting"
fi
ORIGPKG=${1}
SCRATCHDIR=$(basename ${ORIGPKG} .deb)
if [ "${ORIGPKG}" = "${SCRATCHDIR}" ] ; then
    die 7 "${ORIGPKG}'s name doesn't end in '.deb', so quitting"
fi
if [ $(id -u) -ne 0 ] ;then
    die 6 "This script needs to run as root, quitting"
fi

if [ -e "${SCRATCHDIR}" ] ; then
    unset ANSWER
    while true ; do
	echo "${SCRATCHDIR} already exists. Remove?"
	read -p [y/n] ANSWER
	case ${ANSWER} in
	    'y'|'Y' )
		rm -rf ${SCRATCHDIR} || die 8 "Failed to remove ${SCRATCHDIR}"
		break
		;;
	    'n'|'N' )
		exit 0
		;;
	esac
    done
fi
mkdir -p "${SCRATCHDIR}/DEBIAN" || die 3 "Couldn't create temporary directory ${SCRATCHDIR} with subdir DEBIAN"

# Unpack the original
dpkg-deb -x "${ORIGPKG}" ${SCRATCHDIR} || die 4 "Couldn't unpack ${ORIGPKG} to ${SCRATCHDIR}"
dpkg-deb -e "${ORIGPKG}" ${SCRATCHDIR}/DEBIAN || die 5 "Couldn't unpack meta-information from ${ORIGPKG} into ${SCRATCHDIR}/DEBIAN"

####
# Fix: architecture amd64 not recognized.
#sed -i 's/x86_64/amd64/g' ${SCRATCHDIR}/DEBIAN/{pre,post}{inst,rm}
grep 'i\[0-9\]86' ${SCRATCHDIR}/DEBIAN/{pre,post}{inst,rm}|grep -q amd64 \
    || sed -i '/i\[0-9\]86/ s/grep/egrep/ ; s/i\[0-9\]86/i[0-9]86|x86_64|amd64/' ${SCRATCHDIR}/DEBIAN/{pre,post}{inst,rm}

cat "${SCRATCHDIR}/DEBIAN/control"
#Fix: no dependecy on libmotif nor nspluginwrapper
# Unfix: nspluginwrapper not available on Debian
#grep ^Depends: "${SCRATCHDIR}/DEBIAN/control"| grep libmotif4 \
#    || sed -i 's/^Depends:\ /Depends: libmotif4, /g' "${SCRATCHDIR}/DEBIAN/control"
##    || sed -i 's/^Depends:\ /Depends: libmotif4, nspluginwrapper, /g' "${SCRATCHDIR}/DEBIAN/control"

#sed -i '/^Depends:/ c\Depends: libatk1.0-0, libc6, libc6, libcairo2, libgdk-pixbuf2.0-0, libglib2.0-0, libgtk2.0-0, libpango-1.0-0, libpangocairo-1.0-0, libpng12-0, libx11-6, libxext6, libxinerama1, libxrender1' "${SCRATCHDIR}/DEBIAN/control"

sed -i '/^Depends:/ c\Depends: libatk1.0-0, libc6, libcairo2, libfontconfig1, libfreetype6, libgcc1, libgdk-pixbuf2.0-0, libglib2.0-0, libgstreamer0.10-0, libgstreamer-plugins-base0.10-0, libgtk2.0-0, libpango-1.0-0, libpangocairo-1.0-0, libpangoft2-1.0-0, libpng12-0, libstdc++6, libx11-6, libxaw7, libxerces-c3.1, libxext6, libxinerama1, libxml2, libxmu6, libxrender1, libxt6' "${SCRATCHDIR}/DEBIAN/control"

cat "${SCRATCHDIR}/DEBIAN/control"

####

# Back up the original (if it isn't backed up yet)
SERIAL=0
while true ; do
    BACKUP="${SCRATCHDIR}_backup${SERIAL}.deb"
    if ! [ -e "${BACKUP}" ] || cmp "${ORIGPKG}" "${BACKUP}" ; then
	break
    fi
    SERIAL=$((${SERIAL} + 1))
done
if ! [ -e "${BACKUP}" ] ; then
    echo "Copying ${ORIGPKG} to ${BACKUP}"
    cp "${ORIGPKG}" "${BACKUP}"
else
    echo "Existing backup ${BACKUP} is identical to ${ORIGPKG}. Not backing up again."
fi

#rm -rf  ${SCRATCHDIR}/debian
#ls -l  ${SCRATCHDIR}/DEBIAN

# Put the fixed files back into a package
dpkg-deb -b ${SCRATCHDIR}



rm -rf ${SCRATCHDIR}

cat <<EOF
  Your fixed package is in ${ORIGPKG}.
  Consider running debdiff ${BACKUP} ${ORIGPKG}"

EOF
